@@ -1,5 +1,6 @@
 from sqlglot import exp
 from sqlglot.dialects.dialect import Dialect
+from sqlglot import transforms
 from sqlglot.generator import Generator
 from sqlglot.tokens import Tokenizer, TokenType
 
@@ -15,6 +16,11 @@ class Oracle(Dialect):
             exp.DataType.Type.VARCHAR: "VARCHAR2",
         }
 
+        TRANSFORMS = {
+            **Generator.TRANSFORMS,
+            **transforms.UNALIAS_GROUP,
+        }
+
     class Tokenizer(Tokenizer):
         KEYWORDS = {
             **Tokenizer.KEYWORDS,
