@@ -545,6 +545,10 @@ class ColumnDef(Expression):
     }
 
 
+class Constraint(Expression):
+    arg_types = {"this": True, "expressions": True}
+
+
 class Delete(Expression):
     arg_types = {"with": False, "this": True, "where": False}
 
@@ -557,6 +561,15 @@ class Filter(Expression):
     arg_types = {"this": True, "expression": True}
 
 
+class ForeignKey(Expression):
+    arg_types = {
+        "expressions": True,
+        "reference": False,
+        "delete": False,
+        "update": False,
+    }
+
+
 class From(Expression):
     arg_types = {"expressions": True}
 
@@ -730,6 +743,10 @@ class Qualify(Expression):
     pass
 
 
+class Reference(Expression):
+    arg_types = {"this": True, "expressions": True}
+
+
 class Table(Expression):
     arg_types = {"this": True, "db": False, "catalog": False}
 
@@ -1934,6 +1951,14 @@ class JSONExtractScalar(JSONExtract):
     _sql_names = ["JSON_EXTRACT_SCALAR"]
 
 
+class JSONBExtract(JSONExtract):
+    _sql_names = ["JSONB_EXTRACT"]
+
+
+class JSONBExtractScalar(JSONExtract):
+    _sql_names = ["JSONB_EXTRACT_SCALAR"]
+
+
 class Least(Func):
     arg_types = {"this": True, "expressions": True}
     is_var_len_args = True
@@ -2113,7 +2138,7 @@ class UnixToStr(Func):
 
 
 class UnixToTime(Func):
-    pass
+    arg_types = {"this": True, "scale": False}
 
 
 class UnixToTimeStr(Func):
