@@ -81,6 +81,7 @@ class Parser:
         TokenType.CACHE,
         TokenType.COLLATE,
         TokenType.COMMIT,
+        TokenType.CONSTRAINT,
         TokenType.DEFAULT,
         TokenType.DELETE,
         TokenType.DESC,
@@ -103,6 +104,7 @@ class Parser:
         TokenType.PERCENT,
         TokenType.PRECEDING,
         TokenType.RANGE,
+        TokenType.REFERENCES,
         TokenType.ROWS,
         TokenType.SCHEMA_COMMENT,
         TokenType.SET,
@@ -209,7 +211,34 @@ class Parser:
         TokenType.CROSS,
     }
 
-    COLUMN_OPERATORS = {TokenType.DOT}
+    COLUMN_OPERATORS = {
+        TokenType.DOT: None,
+        TokenType.COLON: lambda self, this, path: self.expression(
+            exp.Bracket,
+            this=this,
+            expressions=[path],
+        ),
+        TokenType.ARROW: lambda self, this, path: self.expression(
+            exp.JSONExtract,
+            this=this,
+            path=path,
+        ),
+        TokenType.DARROW: lambda self, this, path: self.expression(
+            exp.JSONExtractScalar,
+            this=this,
+            path=path,
+        ),
+        TokenType.HASH_ARROW: lambda self, this, path: self.expression(
+            exp.JSONBExtract,
+            this=this,
+            path=path,
+        ),
+        TokenType.DHASH_ARROW: lambda self, this, path: self.expression(
+            exp.JSONBExtractScalar,
+            this=this,
+            path=path,
+        ),
+    }
 
     EXPRESSION_PARSERS = {
         exp.DataType: "_parse_types",
@@ -1336,7 +1365,7 @@ class Parser:
         this = self._parse_bracket(this)
 
         while self._match_set(self.COLUMN_OPERATORS):
-            colon = self._prev.token_type == TokenType.COLON
+            op = self.COLUMN_OPERATORS.get(self._prev.token_type)
             field = self._parse_star() or self._parse_function() or self._parse_id_var()
 
             if isinstance(field, exp.Func):
@@ -1345,12 +1374,8 @@ class Parser:
                 # https://cloud.google.com/bigquery/docs/reference/standard-sql/functions-reference#function_call_rules
                 this = self._replace_columns_with_dots(this)
 
-            if colon:
-                this = self.expression(
-                    exp.Bracket,
-                    this=this,
-                    expressions=[exp.Literal.string(field.this)],
-                )
+            if op:
+                this = op(self, this, exp.Literal.string(field.name))
             elif isinstance(this, exp.Column) and not this.table:
                 this = self.expression(exp.Column, this=field, table=this.this)
             else:
@@ -1447,7 +1472,7 @@ class Parser:
         else:
             expressions = [self._parse_id_var()]
 
-        if not self._match(TokenType.LAMBDA):
+        if not self._match(TokenType.ARROW):
             self._retreat(index)
 
             distinct = self._match(TokenType.DISTINCT)
@@ -1475,7 +1500,10 @@ class Parser:
             self._retreat(index)
             return this
 
-        args = self._parse_csv(lambda: self._parse_column_def(self._parse_field()))
+        args = self._parse_csv(
+            lambda: self._parse_constraint()
+            or self._parse_column_def(self._parse_field())
+        )
         self._match_r_paren()
         return self.expression(exp.Schema, this=this, expressions=args)
 
@@ -1533,6 +1561,55 @@ class Parser:
         options.pop("parsed")
         return self.expression(exp.ColumnDef, this=this, kind=kind, **options)
 
+    def _parse_constraint(self):
+        if not self._match(TokenType.CONSTRAINT):
+            return self._parse_foreign_key()
+
+        this = self._parse_id_var()
+        expressions = []
+
+        while True:
+            constraint = self._parse_foreign_key() or self._parse_function()
+            if not constraint:
+                break
+            expressions.append(constraint)
+
+        return self.expression(exp.Constraint, this=this, expressions=expressions)
+
+    def _parse_foreign_key(self):
+        if not self._match(TokenType.FOREIGN_KEY):
+            return None
+
+        expressions = self._parse_wrapped_id_vars()
+        reference = self._match(TokenType.REFERENCES) and self.expression(
+            exp.Reference,
+            this=self._parse_id_var(),
+            expressions=self._parse_wrapped_id_vars(),
+        )
+        options = {}
+
+        while self._match(TokenType.ON):
+            if not self._match_set((TokenType.DELETE, TokenType.UPDATE)):
+                self.raise_error("Expected DELETE or UPDATE")
+            kind = self._prev.text.lower()
+
+            if self._match(TokenType.NO_ACTION):
+                action = "NO ACTION"
+            elif self._match(TokenType.SET):
+                self._match_set((TokenType.NULL, TokenType.DEFAULT))
+                action = "SET " + self._prev.text.upper()
+            else:
+                self._advance()
+                action = self._prev.text.upper()
+            options[kind] = action
+
+        return self.expression(
+            exp.ForeignKey,
+            expressions=expressions,
+            reference=reference,
+            **options,
+        )
+
     def _parse_bracket(self, this):
         if not self._match(TokenType.L_BRACKET):
             return this
