@@ -36,7 +36,10 @@ class TokenType(AutoName):
     TILDA = auto()
     LSHIFT = auto()
     RSHIFT = auto()
-    LAMBDA = auto()
+    ARROW = auto()
+    DARROW = auto()
+    HASH_ARROW = auto()
+    DHASH_ARROW = auto()
     ANNOTATION = auto()
 
     SPACE = auto()
@@ -97,6 +100,7 @@ class TokenType(AutoName):
     COMMENT_END = auto()
     COMMENT_START = auto()
     COMMIT = auto()
+    CONSTRAINT = auto()
     CREATE = auto()
     CROSS = auto()
     CUBE = auto()
@@ -123,6 +127,7 @@ class TokenType(AutoName):
     FILTER = auto()
     FIRST = auto()
     FOLLOWING = auto()
+    FOREIGN_KEY = auto()
     FULL = auto()
     FUNCTION = auto()
     FROM = auto()
@@ -150,6 +155,7 @@ class TokenType(AutoName):
     MAP = auto()
     MOD = auto()
     NEXT = auto()
+    NO_ACTION = auto()
     NULL = auto()
     OFFSET = auto()
     ON = auto()
@@ -175,6 +181,7 @@ class TokenType(AutoName):
     RECURSIVE = auto()
     REPLACE = auto()
     RESPECT_NULLS = auto()
+    REFERENCES = auto()
     RIGHT = auto()
     RLIKE = auto()
     ROLLUP = auto()
@@ -290,6 +297,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "*": TokenType.STAR,
         "~": TokenType.TILDA,
         "?": TokenType.PLACEHOLDER,
+        "#": TokenType.ANNOTATION,
     }
 
     QUOTES = ["'"]
@@ -308,7 +316,10 @@ class Tokenizer(metaclass=_Tokenizer):
         "!=": TokenType.NEQ,
         "<<": TokenType.LSHIFT,
         ">>": TokenType.RSHIFT,
-        "->": TokenType.LAMBDA,
+        "->": TokenType.ARROW,
+        "->>": TokenType.DARROW,
+        "#>": TokenType.HASH_ARROW,
+        "#>>": TokenType.DHASH_ARROW,
         "ADD ARCHIVE": TokenType.ADD_FILE,
         "ADD ARCHIVES": TokenType.ADD_FILE,
         "ADD FILE": TokenType.ADD_FILE,
@@ -337,6 +348,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "COLLATE": TokenType.COLLATE,
         "COMMENT": TokenType.SCHEMA_COMMENT,
         "COMMIT": TokenType.COMMIT,
+        "CONSTRAINT": TokenType.CONSTRAINT,
         "CREATE": TokenType.CREATE,
         "CROSS": TokenType.CROSS,
         "CUBE": TokenType.CUBE,
@@ -364,6 +376,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "FULL": TokenType.FULL,
         "FUNCTION": TokenType.FUNCTION,
         "FOLLOWING": TokenType.FOLLOWING,
+        "FOREIGN KEY": TokenType.FOREIGN_KEY,
         "FROM": TokenType.FROM,
         "GROUP": TokenType.GROUP,
         "GROUPING SETS": TokenType.GROUPING_SETS,
@@ -386,6 +399,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "LIMIT": TokenType.LIMIT,
         "LOCATION": TokenType.LOCATION,
         "NEXT": TokenType.NEXT,
+        "NO ACTION": TokenType.NO_ACTION,
         "NOT": TokenType.NOT,
         "NULL": TokenType.NULL,
         "OFFSET": TokenType.OFFSET,
@@ -410,6 +424,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "REGEXP": TokenType.RLIKE,
         "REPLACE": TokenType.REPLACE,
         "RESPECT NULLS": TokenType.RESPECT_NULLS,
+        "REFERENCES": TokenType.REFERENCES,
         "RIGHT": TokenType.RIGHT,
         "RLIKE": TokenType.RLIKE,
         "ROLLUP": TokenType.ROLLUP,
@@ -580,8 +595,6 @@ class Tokenizer(metaclass=_Tokenizer):
                 self._scan_number()
             elif self._char == self.identifier:
                 self._scan_identifier()
-            elif self._char == "#":
-                self._scan_annotation()
             else:
                 self._scan_keywords()
         return self.tokens
@@ -636,10 +649,15 @@ class Tokenizer(metaclass=_Tokenizer):
 
         if not word:
             if self._char in self.SINGLE_TOKENS:
-                self._add(self.SINGLE_TOKENS[self._char])
-            else:
-                self._scan_var()
+                token = self.SINGLE_TOKENS[self._char]
+                if token == TokenType.ANNOTATION:
+                    self._scan_annotation()
+                    return
+                self._add(token)
+                return
+            self._scan_var()
             return
+
         if self._scan_comment(word):
             return
         if self._scan_string(word):
